diff --git a/Constants/ConfigurationNodeNames.cs b/Constants/ConfigurationNodeNames.cs
index 49f630c..c921b50 100644
--- a/Constants/ConfigurationNodeNames.cs
+++ b/Constants/ConfigurationNodeNames.cs
@@ -2,6 +2,6 @@ namespace xAiApi.Constants
{
public partial struct ConfigurationNodeNames
{
- public const string AI_API_NODE = "AiAPiConfiguration";
+ public const string AI_API_NODE = "AiApiConfiguration";
}
}
\ No newline at end of file
diff --git a/Controllers/XAiEmbeddingServiceControllerBase.cs b/Controllers/XAiEmbeddingServiceControllerBase.cs
index 3d8064d..42d43d3 100644
--- a/Controllers/XAiEmbeddingServiceControllerBase.cs
+++ b/Controllers/XAiEmbeddingServiceControllerBase.cs
@@ -40,8 +40,8 @@ namespace xAiApi.Controllers
///
///
[AllowAnonymous]
- [HttpGet("Embeding")]
- public async Task> Embeding(
+ [HttpGet("Embedding")]
+ public async Task> Embedding(
[FromQuery] string content,
CancellationToken cancellationToken = default
)
@@ -54,7 +54,7 @@ namespace xAiApi.Controllers
ValidationProvider.NotEmpty(content);
//
- var result = await aiService.Embeding(
+ var result = await aiService.Embedding(
content: content,
cancellationToken: cancellationToken
);
@@ -77,8 +77,8 @@ namespace xAiApi.Controllers
///
///
[AllowAnonymous]
- [HttpGet("Embedings")]
- public async Task>> Embedings(
+ [HttpGet("Embeddings")]
+ public async Task>> Embeddings(
[FromQuery] string[] batch,
CancellationToken cancellationToken = default
)
@@ -91,7 +91,7 @@ namespace xAiApi.Controllers
ValidationProvider.NotZeroChilds(batch);
//
- var result = await aiService.Embedings(
+ var result = await aiService.Embeddings(
batch: batch,
cancellationToken: cancellationToken
);
diff --git a/Interfaces/IXAiEmbeddingServiceBase.cs b/Interfaces/IXAiEmbeddingServiceBase.cs
index 8ef4c54..00d5644 100644
--- a/Interfaces/IXAiEmbeddingServiceBase.cs
+++ b/Interfaces/IXAiEmbeddingServiceBase.cs
@@ -16,7 +16,7 @@ namespace xAiApi.Interfaces
///
///
///
- Task Embeding(
+ Task Embedding(
string content,
CancellationToken cancellationToken = default
);
@@ -27,7 +27,7 @@ namespace xAiApi.Interfaces
///
///
///
- Task> Embedings(
+ Task> Embeddings(
string[] batch,
CancellationToken cancellationToken = default
);
diff --git a/Interfaces/IXAiEmbeddingServiceControllerBase.cs b/Interfaces/IXAiEmbeddingServiceControllerBase.cs
index f9e9294..95b828f 100644
--- a/Interfaces/IXAiEmbeddingServiceControllerBase.cs
+++ b/Interfaces/IXAiEmbeddingServiceControllerBase.cs
@@ -13,8 +13,8 @@ namespace xAiApi.Interfaces
///
///
///
- [HttpGet("Embeding")]
- Task> Embeding(
+ [HttpGet("Embedding")]
+ Task> Embedding(
[FromQuery] string content,
CancellationToken cancellationToken = default
);
@@ -25,8 +25,8 @@ namespace xAiApi.Interfaces
///
///
///
- [HttpGet("Embedings")]
- Task>> Embedings(
+ [HttpGet("Embeddings")]
+ Task>> Embeddings(
[FromQuery] string[] batch,
CancellationToken cancellationToken = default
);
diff --git a/appsettings.Development.json b/appsettings.Development.json
index 5032b0c..dd8c63f 100644
--- a/appsettings.Development.json
+++ b/appsettings.Development.json
@@ -35,7 +35,7 @@
"ThumbQuality": 72,
"MaxFileSize": 41943040
},
- "AiAPiConfiguration": {
+ "AiApiConfiguration": {
"Models": [
{
"ApiKey": "",
diff --git a/Providers/XAiEmbeddingServiceBase.cs b/Providers/XAiEmbeddingServiceBase.cs
index 55b5407..34d087e 100644
--- a/Providers/XAiEmbeddingServiceBase.cs
+++ b/Providers/XAiEmbeddingServiceBase.cs
@@ -51,7 +51,7 @@ namespace xAiApi.Providers
///
///
///
- public virtual async Task Embeding(
+ public virtual async Task Embedding(
string content,
CancellationToken cancellationToken = default
)
@@ -68,7 +68,7 @@ namespace xAiApi.Providers
using var client = GetEmbeddingClient();
//
// Create Embeding Request ....
var request = new EmbedRequest
{
Input = [content],
@@ -111,7 +111,7 @@ namespace xAiApi.Providers
///
///
///
- public virtual async Task> Embedings(
+ public virtual async Task> Embeddings(
string[] batch,
CancellationToken cancellationToken = default
)
@@ -130,7 +130,7 @@ namespace xAiApi.Providers
using var client = GetEmbeddingClient();
//
// Create Embeding Request ....
var request = new EmbedRequest
{
Input = [.. batch],
@@ -68,7 +68,7 @@ namespace xAiApi.Providers
using var client = GetEmbeddingClient();
//
- // Create Embeding Request ....
+ // Create Embedding Request ....
var request = new EmbedRequest
{
@@ -130,7 +130,7 @@ namespace xAiApi.Providers
using var client = GetEmbeddingClient();
//
- // Create Embeding Request ....
+ // Create Embedding Request ....
var request = new EmbedRequest
{